#!/usr/bin/python
# -*- coding: utf-8 -*-

"""
SAT plugin for managing xep-0077
Copyright (C) 2009  Jérôme Poisson (goffi@goffi.org)

This program is free software: you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation, either version 3 of the License, or
(at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program.  If not, see <http://www.gnu.org/licenses/>.
"""

from logging import debug, info, error
from twisted.words.protocols.jabber import client, jid, xmlstream, error
from twisted.words.protocols.jabber.xmlstream import IQ
from twisted.internet import reactor
import pdb

NS_REG = 'jabber:iq:register'

PLUGIN_INFO = {
"name": "XEP 0077 Plugin",
"import_name": "XEP_0077",
"type": "XEP",
"dependencies": [],
"main": "XEP_0077",
"description": """Implementation of SI File Transfert"""
}

class XEP_0077():

    def __init__(self, host):
        info("Plugin XEP_0077 initialization")
        self.host = host
        host.bridge.addMethod("in_band_register", ".communication", in_sign='s', out_sign='s', method=self.in_band_register)
   
    def reg_ok(self, answer):
        """Called after the first get IQ"""
        print "answer:",answer

    def reg_err(self, failure):
        """Called when something is wrong with registration"""
        info ("Registration failure: %s" % str(failure.value))
        answer_data = {}
        answer_data['reason'] = 'unknown'
        answer_data={"message":"%s [code: %s]" % (failure.value.condition, failure.value.code)}
        answer_type = "ERROR"
        self.host.bridge.actionResult(answer_type, failure.value.stanza['id'], answer_data)
   
    def in_band_register(self, target):
        """register to a target JID"""
        to_jid = jid.JID(target)
        debug("Asking registration for [%s]" % target)
        reg_request=IQ(self.host.xmlstream,'get')
        reg_request["from"]=self.host.me.full()
        reg_request["to"] = to_jid.full()
        query=reg_request.addElement('query', NS_REG)
        reg_request.send(to_jid.full()).addCallbacks(self.reg_ok, self.reg_err)
        return reg_request["id"] 
